@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 #!! When the documentation below is updated, setup.py should be
 # checked for consistency.
@@ -114,9 +113,10 @@ function--defined only if the NumPy module is available).
 generally return AffineScalarFunc objects, which also print as a value
 with uncertainty.  Their most useful attributes and methods are
 described in the documentation for AffineScalarFunc.  Note that
-Variable objects are also AffineScalarFunc objects: testing whether a
-value carries an uncertainty handled by this module should be done
-with insinstance(my_value, AffineScalarFunc).
+Variable objects are also AffineScalarFunc objects.  UFloat is an
+alias for AffineScalarFunc, provided as a convenience: testing whether
+a value carries an uncertainty handled by this module should be done
+with insinstance(my_value, UFloat).
 
 - Mathematically, numbers with uncertainties are, in this package,
 probability distributions.  These probabilities are reduced to two
@@ -211,11 +211,6 @@ is the result of x != 0.
 - This package contains tests.  They can be run either manually or
 automatically with the nose unit testing framework (nosetests).
 
-- The author wishes to thank Arnaud Delobelle, Pierre Cladé, Joaquim
-Abian and contributors to the comp.lang.python newsgroup for valuable
-input.  Thank you also for all the feedback I received from other
-users, which helped improve this program.
-
 (c) 2009-2010 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>.
 Please send feature requests, bug reports, or feedback to this address.
 
@@ -241,7 +236,7 @@ from math import sqrt, log  # Optimization: no attribute look-up
 import copy
 
 # Numerical version:
-__version_info__ = (1, 5, 5)
+__version_info__ = (1, 6, 0)
 __version__ = '.'.join(str(num) for num in __version_info__)
 
 __author__ = 'Eric O. LEBIGOT (EOL)'
@@ -262,12 +257,11 @@ __all__ = [
     # Utility functions (more are exported if NumPy is present):
     'covariance_matrix',
     
-    # Class returned by most operations: not typically created by
-    # users (except through the Variable subclass), but possibly
-    # manipulated by external code ['derivatives()' method, etc.];
-    # useful for testing whether a result is an expression with
-    # uncertainty:
-    'AffineScalarFunc',
+    # Class for testing whether an object is a number with
+    # uncertainty.  Not usually created by users (except through the
+    # Variable subclass), but possibly manipulated by external code
+    # ['derivatives()' method, etc.].
+    'UFloat',
 
     # Wrapper for allowing non-pure-Python function to handle
     # quantitites with uncertainties:
@@ -382,11 +376,12 @@ class NumericalDerivatives(object):
   
 def wrap(f, derivatives_funcs=None):
     """
-    Wraps function f so that, when applied to AffineScalarFunc
-    objects or float-like arguments, f returns a local approximation
-    of its values (in the form of an object of class AffineScalarFunc).
-    In this case, if none of the arguments of f involves variables
-    [i.e. Variable objects], f simply returns its usual result.
+    Wraps function f so that, when applied to numbers with
+    uncertainties (AffineScalarFunc objects) or float-like arguments,
+    f returns a local approximation of its values (in the form of an
+    object of class AffineScalarFunc).  In this case, if none of the
+    arguments of f involves variables [i.e. Variable objects], f
+    simply returns its usual result.
 
     When f is not called on AffineScalarFunc or float-like
     arguments, the original result of f is returned.
@@ -659,6 +654,8 @@ class AffineScalarFunc(object):
     (addition, etc.).  Such functions can for instance be used for
     representing the local (linear) behavior of any function.
 
+    This class is mostly meant to be used internally.
+
     This class can also be used to represent constants.
 
     The variables of affine scalar functions are Variable objects.
@@ -922,6 +919,8 @@ class AffineScalarFunc(object):
         for (name, value) in data_dict.iteritems():
             setattr(self, name, value)
 
+# Nicer name, for users: isinstance(ufloat(...), UFloat) is True:
+UFloat = AffineScalarFunc
 
 def get_ops_with_reflection():
 
@@ -1210,8 +1209,9 @@ def std_dev(x):
 def covariance_matrix(functions):
     """
     Returns a matrix that contains the covariances between the given
-    sequence of AffineScalarFunc objects.  The resulting matrix
-    implicitly depends on their ordering in 'functions'.
+    sequence of numbers with uncertainties (AffineScalarFunc objects).
+    The resulting matrix implicitly depends on their ordering in
+    'functions'.
 
     The covariances are floats (never int objects).
 
@@ -1259,9 +1259,9 @@ else:
     
     def correlated_values(values, covariance_mat, tags=None):
         """
-        Returns AffineScalarFunc objects that correctly reproduce the
-        given covariance matrix, and have the given values as their
-        nominal value.
+        Returns numbers with uncertainties (AffineScalarFunc objects)
+        that correctly reproduce the given covariance matrix, and have
+        the given values as their nominal value.
 
         The list of values and the covariance matrix must have the
         same length, and the matrix must be a square (symmetric) one.
